security: Change SHA256_DIGEST_LENGTH to SHA256_DIGEST_SIZE;

Change-Id: Ib490cfec5e9331575567b346810d1bc56bc97ea1
diff --git a/src/util/crypto.hpp b/src/util/crypto.hpp
index 21e1e71..58555a2 100644
--- a/src/util/crypto.hpp
+++ b/src/util/crypto.hpp
@@ -12,19 +12,22 @@
 namespace ndn {
 
 /**
- * Compute the sha-256 digest of data.
+ * @brief Compute the sha-256 digest of data.
+ *
  * @param data Pointer to the input byte array.
  * @param dataLength The length of data.
  * @param digest A pointer to a buffer of size SHA256_DIGEST_LENGTH to receive the data.
  */
 void ndn_digestSha256(const uint8_t *data, size_t dataLength, uint8_t *digest);
 
 namespace crypto {
 
-static size_t SHA256_DIGEST_LENGTH = 32;
+/// @brief number of octets in a SHA256 digest
+static const size_t SHA256_DIGEST_SIZE = 32;
 
 /**
- * Compute the sha-256 digest of data.
+ * @brief Compute the sha-256 digest of data.
+ *
  * @param data Pointer to the input byte array.
  * @param dataLength The length of data.
  * @return A pointer to a buffer of SHA256_DIGEST.
@@ -12,19 +12,22 @@
  * @param data Pointer to the input byte array.
  * @param dataLength The length of data.
- * @param digest A pointer to a buffer of size SHA256_DIGEST_LENGTH to receive the data.
+ * @param digest A pointer to a buffer of size crypto::SHA256_DIGEST_SIZE to receive the data.
  */
 void ndn_digestSha256(const uint8_t *data, size_t dataLength, uint8_t *digest);